
# pypaq

little python tools, useful mainly for tasks related to Machine Learning etc.

-----------------

### naming conventions

Naming conventions used in pypaq code:

| pattern      | description |
|--------------| ---         
| general      
| n_*          | number of * 
| *L           | list      
| *D           | dict
| *_ix         | index
| *_id         | id
| *AV          | average
| *F           | factor (usually 0.0-1.0) 
| *P, *_prob   | probability (0.0-1.0)
| paths        
| *_dir, *_DIR | directory, folder, relative or absolute
| *_fn, *_FN   | file name (without dir)
| *_fp, *_FP   | full path (dir + file_name), relative or absolute
